@@ -132,10 +132,10 @@ class BalanceComp(ImplicitComponent):
             (see `add_output` method).
         """
         if 'guess_func' in kwargs:
-            super(BalanceComp, self).__init__(guess_func=kwargs['guess_func'])
+            super().__init__(guess_func=kwargs['guess_func'])
             kwargs.pop('guess_func')
         else:
-            super(BalanceComp, self).__init__()
+            super().__init__()
 
         self._state_vars = {}
 
@@ -314,7 +314,13 @@ class BalanceComp(ImplicitComponent):
 
         self._state_vars[name] = options
 
-        if val is not None:
+        if val is None:
+            # If user doesn't specify initial guess for val, we can size problem from initial
+            # rhs_val.
+            if 'shape' not in kwargs and not np.isscalar(rhs_val):
+                kwargs['shape'] = rhs_val.shape
+
+        else:
             options['kwargs']['val'] = val
 
         meta = self.add_output(name, **options['kwargs'])
