@@ -40,7 +40,7 @@ class CrossProductComp(ExplicitComponent):
         **kwargs : dict of keyword arguments
             Keyword arguments that will be mapped into the Component options.
         """
-        super(CrossProductComp, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self._products = []
 
