@@ -15,7 +15,7 @@ VAR_RGX = re.compile(r'([.]*[_a-zA-Z]\w*[ ]*\(?)')
 # Names of metadata entries allowed for ExecComp variables.
 _allowed_meta = {'value', 'shape', 'units', 'res_units', 'desc',
                  'ref', 'ref0', 'res_ref', 'lower', 'upper', 'src_indices',
-                 'flat_src_indices', 'tags'}
+                 'flat_src_indices', 'tags', 'shape_by_conn', 'copy_shape'}
 
 # Names that are not allowed for input or output variables (keywords for options)
 _disallowed_names = {'has_diag_partials', 'units', 'shape'}
@@ -209,7 +209,7 @@ class ExecComp(ExplicitComponent):
             if name in kwargs:
                 options[name] = kwargs.pop(name)
 
-        super(ExecComp, self).__init__(**options)
+        super().__init__(**options)
 
         # if complex step is used for derivatives, this is the stepsize
         self.complex_stepsize = 1.e-40
@@ -289,6 +289,12 @@ class ExecComp(ExplicitComponent):
                     init_vals[arg] = val['value']
                     del kwargs2[arg]['value']
 
+                if 'shape_by_conn' in val or 'copy_shape' in val:
+                    if val.get('shape') is not None or val.get('value') is not None:
+                        raise RuntimeError(f"{self.msginfo}: Can't set 'shape' or 'value' for "
+                                           f"variable '{arg}' along with 'copy_shape' or "
+                                           "'shape_by_conn'.")
+
                 if 'shape' in val:
                     if arg not in init_vals:
                         init_vals[arg] = np.ones(val['shape'])
@@ -302,40 +308,44 @@ class ExecComp(ExplicitComponent):
                 init_vals[arg] = val
 
         for var in sorted(allvars):
+            meta = kwargs2.get(var, {'units': units, 'shape': shape})
+
             # if user supplied an initial value, use it, otherwise set to 1.0
             if var in init_vals:
                 val = init_vals[var]
             else:
                 init_vals[var] = val = 1.0
 
-            meta = kwargs2.get(var, {'units': units, 'shape': shape})
-
             if var in outs:
                 self.add_output(var, val, **meta)
             else:
                 self.add_input(var, val, **meta)
 
-        if self.options['has_diag_partials']:
-            # check that sizes of any input/output vars match or one of them is size 1
-            osorted = sorted(self._var_rel_names['output'])
-            for inp in sorted(self._var_rel_names['input']):
-                ival = init_vals[inp]
-                iarray = isinstance(ival, ndarray) and ival.size > 1
-                for out in osorted:
-                    oval = init_vals[out]
-                    if iarray and isinstance(oval, ndarray) and oval.size > 1:
-                        if oval.size != ival.size:
-                            raise RuntimeError("%s: has_diag_partials is True but partial(%s, %s) "
-                                               "is not square (shape=(%d, %d))." %
-                                               (self.msginfo, out, inp, oval.size, ival.size))
-                        # partial will be declared as diagonal
-                        inds = np.arange(oval.size, dtype=int)
+        for expr in self._exprs:
+            lhs, _ = expr.split('=', 1)
+            outs = self._parse_for_out_vars(lhs)
+            all = self._parse_for_vars(expr)  # gets in and out
+            ins = sorted(set(all) - set(outs))
+            outs = sorted(outs)
+            for out in outs:
+                for inp in ins:
+                    if self.options['has_diag_partials']:
+                        ival = init_vals[inp]
+                        iarray = isinstance(ival, ndarray) and ival.size > 1
+                        oval = init_vals[out]
+                        if iarray and isinstance(oval, ndarray) and oval.size > 1:
+                            if oval.size != ival.size:
+                                raise RuntimeError(
+                                    "%s: has_diag_partials is True but partial(%s, %s) "
+                                    "is not square (shape=(%d, %d))." %
+                                    (self.msginfo, out, inp, oval.size, ival.size))
+                            # partial will be declared as diagonal
+                            inds = np.arange(oval.size, dtype=int)
+                        else:
+                            inds = None
+                        self.declare_partials(of=out, wrt=inp, rows=inds, cols=inds)
                     else:
-                        inds = None
-                    self.declare_partials(of=out, wrt=inp, rows=inds, cols=inds)
-        else:
-            # All derivatives are defined as dense
-            self.declare_partials(of='*', wrt='*')
+                        self.declare_partials(of=out, wrt=inp)
 
         self._codes = self._compile_exprs(self._exprs)
 
@@ -456,7 +466,8 @@ class ExecComp(ExplicitComponent):
                 self.compute(pwrap, uwrap)
 
                 for u in out_names:
-                    partials[(u, input)] = imag(uwrap[u] * inv_stepsize).flat
+                    if (u, input) in self._declared_partials:
+                        partials[(u, input)] = imag(uwrap[u] * inv_stepsize).flat
 
                 # restore old input value
                 pwrap[input] -= step
@@ -472,8 +483,9 @@ class ExecComp(ExplicitComponent):
                     self.compute(pwrap, uwrap)
 
                     for u in out_names:
-                        # set the column in the Jacobian entry
-                        partials[(u, input)][:, i] = imag(uwrap[u] * inv_stepsize).flat
+                        if (u, input) in self._declared_partials:
+                            # set the column in the Jacobian entry
+                            partials[(u, input)][:, i] = imag(uwrap[u] * inv_stepsize).flat
 
                     # restore old input value
                     pwrap[input][idx] -= step
@@ -568,18 +580,13 @@ class _IODict(object):
         self._inputs = inputs
 
     def __getitem__(self, name):
-        if name in self._outputs:
-            return self._outputs[name]
-        else:
+        try:
             return self._inputs[name]
+        except KeyError:
+            return self._outputs[name]
 
     def __setitem__(self, name, value):
-        if name in self._outputs:
-            self._outputs[name] = value
-        elif name in self._inputs:
-            self._inputs[name] = value
-        else:
-            self._outputs[name] = value  # will raise KeyError
+        self._outputs[name] = value
 
     def __contains__(self, name):
         return name in self._outputs or name in self._inputs
