@@ -281,7 +281,7 @@ class TestExecComp(unittest.TestCase):
         with self.assertRaises(Exception) as context:
             prob.setup()
         self.assertEqual(str(context.exception),
-                         "ExecComp (C1): No valid expressions provided to ExecComp(): [].")
+                         "'C1' <class ExecComp>: No valid expressions provided to ExecComp(): [].")
 
     def test_colon_vars(self):
         prob = om.Problem()
@@ -289,7 +289,7 @@ class TestExecComp(unittest.TestCase):
         with self.assertRaises(Exception) as context:
             prob.setup()
         self.assertEqual(str(context.exception),
-                         "ExecComp (C1): failed to compile expression 'y=foo:bar+1.'.")
+                         "'C1' <class ExecComp>: failed to compile expression 'y=foo:bar+1.'.")
 
     def test_bad_kwargs(self):
         prob = om.Problem()
@@ -297,7 +297,7 @@ class TestExecComp(unittest.TestCase):
         with self.assertRaises(Exception) as context:
             prob.setup()
         self.assertEqual(str(context.exception),
-                         "ExecComp (C1): arg 'xx' in call to ExecComp() does not refer to any variable "
+                         "'C1' <class ExecComp>: arg 'xx' in call to ExecComp() does not refer to any variable "
                          "in the expressions ['y=x+1.']")
 
     def test_bad_kwargs_meta(self):
@@ -307,7 +307,7 @@ class TestExecComp(unittest.TestCase):
         with self.assertRaises(Exception) as context:
             prob.setup()
         self.assertEqual(str(context.exception),
-                         "ExecComp (C1): the following metadata names were not recognized for "
+                         "'C1' <class ExecComp>: the following metadata names were not recognized for "
                          "variable 'x': ['high', 'low', 'val']")
 
     def test_name_collision_const(self):
@@ -316,7 +316,7 @@ class TestExecComp(unittest.TestCase):
         with self.assertRaises(Exception) as context:
             prob.setup()
         self.assertEqual(str(context.exception),
-                         "ExecComp (C1): cannot assign to variable 'e' because it's already defined "
+                         "'C1' <class ExecComp>: cannot assign to variable 'e' because it's already defined "
                          "as an internal function or constant.")
 
     def test_name_collision_func(self):
@@ -325,7 +325,7 @@ class TestExecComp(unittest.TestCase):
         with self.assertRaises(Exception) as context:
             prob.setup()
         self.assertEqual(str(context.exception),
-                         "ExecComp (C1): cannot assign to variable 'sin' because it's already defined "
+                         "'C1' <class ExecComp>: cannot assign to variable 'sin' because it's already defined "
                          "as an internal function or constant.")
 
     def test_func_as_rhs_var(self):
@@ -334,7 +334,7 @@ class TestExecComp(unittest.TestCase):
         with self.assertRaises(Exception) as context:
             prob.setup()
         self.assertEqual(str(context.exception),
-                         "ExecComp (C1): cannot use 'sin' as a variable because it's already defined "
+                         "'C1' <class ExecComp>: cannot use 'sin' as a variable because it's already defined "
                          "as an internal function.")
 
     def test_mixed_type(self):
@@ -441,7 +441,7 @@ class TestExecComp(unittest.TestCase):
             prob.setup()
 
         self.assertEqual(str(cm.exception),
-                         "ExecComp (C1): cannot use variable name 'units' because it's a reserved keyword.")
+                         "'C1' <class ExecComp>: cannot use variable name 'units' because it's a reserved keyword.")
 
     def test_common_units(self):
         # all variables in the ExecComp have the same units
@@ -484,111 +484,93 @@ class TestExecComp(unittest.TestCase):
             prob.setup()
 
         self.assertEqual(str(cm.exception),
-                         "ExecComp (C1): units of 'km' have been specified for variable 'x', but "
+                         "'C1' <class ExecComp>: units of 'km' have been specified for variable 'x', but "
                          "units of 'm' have been specified for the entire component.")
 
     def test_shape_and_value(self):
         p = om.Problem()
         model = p.model
-        model.add_subsystem('indep', om.IndepVarComp('x', val=np.ones(5)))
 
         model.add_subsystem('comp', om.ExecComp('y=3.0*x + 2.5',
                                                 x={'shape': (5,), 'value': np.zeros(5)},
                                                 y={'shape': (5,), 'value': np.zeros(5)}))
 
-        model.connect('indep.x', 'comp.x')
-
         p.setup()
         p.run_model()
 
-        J = p.compute_totals(of=['comp.y'], wrt=['indep.x'], return_format='array')
+        J = p.compute_totals(of=['comp.y'], wrt=['comp.x'], return_format='array')
 
         assert_almost_equal(J, np.eye(5)*3., decimal=6)
 
     def test_conflicting_shape(self):
         p = om.Problem()
         model = p.model
-        model.add_subsystem('indep', om.IndepVarComp('x', val=np.ones(5)))
 
         model.add_subsystem('comp', om.ExecComp('y=3.0*x + 2.5',
                                                 x={'shape': (5,), 'value': 5},
                                                 y={'shape': (5,)}))
 
-        model.connect('indep.x', 'comp.x')
-
         with self.assertRaises(Exception) as context:
             p.setup()
 
         self.assertEqual(str(context.exception).replace('L,', ','),  # L on Windows
-                         "ExecComp (comp): shape of (5,) has been specified for variable 'x', "
+                         "'comp' <class ExecComp>: shape of (5,) has been specified for variable 'x', "
                          "but a value of shape (1,) has been provided.")
 
     def test_common_shape(self):
         p = om.Problem()
         model = p.model
-        model.add_subsystem('indep', om.IndepVarComp('x', val=np.ones(5)))
 
         model.add_subsystem('comp', om.ExecComp('y=3.0*x + 2.5', shape=(5,)))
 
-        model.connect('indep.x', 'comp.x')
-
         p.setup()
         p.run_model()
 
-        J = p.compute_totals(of=['comp.y'], wrt=['indep.x'], return_format='array')
+        J = p.compute_totals(of=['comp.y'], wrt=['comp.x'], return_format='array')
 
         assert_almost_equal(J, np.eye(5)*3., decimal=6)
 
     def test_common_shape_with_values(self):
         p = om.Problem()
         model = p.model
-        model.add_subsystem('indep', om.IndepVarComp('x', val=np.ones(5)))
 
         model.add_subsystem('comp', om.ExecComp('y=3.0*x + 2.5', shape=(5,),
                                                 x={'value': np.zeros(5)},
                                                 y={'value': np.zeros(5)}))
 
-        model.connect('indep.x', 'comp.x')
-
         p.setup()
         p.run_model()
 
-        J = p.compute_totals(of=['comp.y'], wrt=['indep.x'], return_format='array')
+        J = p.compute_totals(of=['comp.y'], wrt=['comp.x'], return_format='array')
 
         assert_almost_equal(J, np.eye(5)*3., decimal=6)
 
     def test_common_shape_conflicting_shape(self):
         p = om.Problem()
         model = p.model
-        model.add_subsystem('indep', om.IndepVarComp('x', val=np.ones(5)))
 
         model.add_subsystem('comp', om.ExecComp('y=3.0*x + 2.5', shape=(5,),
                                                 y={'shape': (10,)}))
 
-        model.connect('indep.x', 'comp.x')
-
         with self.assertRaises(Exception) as context:
             p.setup()
 
         self.assertEqual(str(context.exception).replace('L,', ','),  # L on Windows
-                         "ExecComp (comp): shape of (10,) has been specified for variable 'y', "
+                         "'comp' <class ExecComp>: shape of (10,) has been specified for variable 'y', "
                          "but shape of (5,) has been specified for the entire component.")
 
     def test_common_shape_conflicting_value(self):
         p = om.Problem()
         model = p.model
-        model.add_subsystem('indep', om.IndepVarComp('x', val=np.ones(5)))
 
         model.add_subsystem('comp', om.ExecComp('y=3.0*x + 2.5', shape=(5,),
                                                 x={'value': 5}))
 
-        model.connect('indep.x', 'comp.x')
-
         with self.assertRaises(Exception) as context:
             p.setup()
 
         self.assertEqual(str(context.exception).replace('1L,', '1,'),  # 1L on Windows
-                         "ExecComp (comp): value of shape (1,) has been specified for variable 'x', "
+                         "'comp' <class ExecComp>: value of shape (1,) has been specified for variable 'x', "
                          "but shape of (5,) has been specified for the entire component.")
 
     def test_math(self):
@@ -617,7 +599,7 @@ class TestExecComp(unittest.TestCase):
           prob.run_model()
 
         self.assertEqual(str(context.exception),
-            "ExecComp (C1): Error occurred evaluating 'y2=np.cos(x)'\n"
+            "'C1' <class ExecComp>: Error occurred evaluating 'y2=np.cos(x)'\n"
             "    ExecComp supports a subset of numpy functions directly, without the 'np' prefix.\n"
             "    'cos' is supported (See the documentation).")
 
@@ -630,7 +612,7 @@ class TestExecComp(unittest.TestCase):
           prob.run_model()
 
         self.assertEqual(str(context.exception),
-            "ExecComp (C1): Error occurred evaluating 'y=numpy.sin(x)'\n"
+            "'C1' <class ExecComp>: Error occurred evaluating 'y=numpy.sin(x)'\n"
             "    ExecComp supports a subset of numpy functions directly, without the 'numpy' prefix.\n"
             "    'sin' is supported (See the documentation).")
 
@@ -643,7 +625,7 @@ class TestExecComp(unittest.TestCase):
           prob.run_model()
 
         self.assertEqual(str(context.exception),
-            "ExecComp (C1): Error occurred evaluating 'y=numpy.fft(x)'\n"
+            "'C1' <class ExecComp>: Error occurred evaluating 'y=numpy.fft(x)'\n"
             "    ExecComp supports a subset of numpy functions directly, without the 'numpy' prefix.\n"
             "    'fft' is not supported (See the documentation).")
 
@@ -687,13 +669,10 @@ class TestExecComp(unittest.TestCase):
 
     def test_simple_array_model(self):
         prob = om.Problem()
-        prob.model.add_subsystem('p1', om.IndepVarComp('x', np.ones([2])))
         prob.model.add_subsystem('comp', om.ExecComp(['y[0]=2.0*x[0]+7.0*x[1]',
                                                       'y[1]=5.0*x[0]-3.0*x[1]'],
                                                      x=np.zeros([2]), y=np.zeros([2])))
 
-        prob.model.connect('p1.x', 'comp.x')
-
         prob.setup()
         prob.set_solver_print(level=0)
         prob.run_model()
@@ -704,13 +683,10 @@ class TestExecComp(unittest.TestCase):
 
     def test_simple_array_model2(self):
         prob = om.Problem()
-        prob.model.add_subsystem('p1', om.IndepVarComp('x', np.ones([2])))
         prob.model.add_subsystem('comp', om.ExecComp('y = mat.dot(x)',
                                                      x=np.zeros((2,)), y=np.zeros((2,)),
                                                      mat=np.array([[2., 7.], [5., -3.]])))
 
-        prob.model.connect('p1.x', 'comp.x')
-
         prob.setup()
         prob.set_solver_print(level=0)
         prob.run_model()
@@ -742,22 +718,20 @@ class TestExecComp(unittest.TestCase):
 
     def test_complex_step2(self):
         prob = om.Problem(om.Group())
-        prob.model.add_subsystem('p1', om.IndepVarComp('x', 2.0))
-        prob.model.add_subsystem('comp', om.ExecComp('y=x*x + x*2.0'))
-        prob.model.connect('p1.x', 'comp.x')
+        prob.model.add_subsystem('comp', om.ExecComp('y=x*x + x*2.0', x=2.0))
         prob.set_solver_print(level=0)
 
         prob.setup(check=False, mode='fwd')
         prob.run_model()
 
-        J = prob.compute_totals(['comp.y'], ['p1.x'], return_format='flat_dict')
-        assert_near_equal(J['comp.y', 'p1.x'], np.array([[6.0]]), 0.00001)
+        J = prob.compute_totals(['comp.y'], ['comp.x'], return_format='flat_dict')
+        assert_near_equal(J['comp.y', 'comp.x'], np.array([[6.0]]), 0.00001)
 
         prob.setup(check=False, mode='rev')
         prob.run_model()
 
-        J = prob.compute_totals(['comp.y'], ['p1.x'], return_format='flat_dict')
-        assert_near_equal(J['comp.y', 'p1.x'], np.array([[6.0]]), 0.00001)
+        J = prob.compute_totals(['comp.y'], ['comp.x'], return_format='flat_dict')
+        assert_near_equal(J['comp.y', 'comp.x'], np.array([[6.0]]), 0.00001)
 
     def test_abs_complex_step(self):
         prob = om.Problem()
@@ -818,43 +792,139 @@ class TestExecComp(unittest.TestCase):
     def test_has_diag_partials_error(self):
         p = om.Problem()
         model = p.model
-        model.add_subsystem('indep', om.IndepVarComp('x', val=np.ones(3)))
-        model.add_design_var('indep.x')
 
         mat = np.arange(15).reshape((3,5))
-        model.add_subsystem('comp', om.ExecComp('y=A.dot(x)', has_diag_partials=True, A=mat, x=np.ones(5), y=np.ones(3)))
-        model.connect('indep.x', 'comp.x')
+        model.add_subsystem('comp', om.ExecComp('y=A.dot(x)', has_diag_partials=True, A=mat,
+                                                x=np.ones(5), y=np.ones(3)))
 
         with self.assertRaises(Exception) as context:
             p.setup()
         self.assertEqual(str(context.exception),
-                         "ExecComp (comp): has_diag_partials is True but partial(y, A) is not square (shape=(3, 15)).")
+                         "'comp' <class ExecComp>: has_diag_partials is True but partial(y, A) is not square (shape=(3, 15)).")
+
+    def test_has_diag_partials(self):
+        # Really check to see that the has_diag_partials argument had its intended effect
+
+        # run with has_diag_partials=False
+        p = om.Problem()
+        model = p.model
+        comp = om.ExecComp('y=3.0*x + 2.5', has_diag_partials=False, x=np.ones(5), y=np.ones(5))
+        model.add_subsystem('comp', comp)
+        p.setup()
+
+        declared_partials = comp._declared_partials[('y','x')]
+        self.assertTrue('rows' not in declared_partials )
+        self.assertTrue('cols' not in declared_partials )
+
+        # run with has_diag_partials=True
+        p = om.Problem()
+        model = p.model
+        comp = om.ExecComp('y=3.0*x + 2.5', has_diag_partials=True, x=np.ones(5), y=np.ones(5))
+        model.add_subsystem('comp', comp)
+        p.setup()
+
+        declared_partials = comp._declared_partials[('y','x')]
+        self.assertTrue('rows' in declared_partials )
+        self.assertListEqual([0,1,2,3,4], list( comp._declared_partials[('y','x')]['rows']))
+        self.assertTrue('cols' in declared_partials )
+        self.assertListEqual([0,1,2,3,4], list( comp._declared_partials[('y','x')]['cols']))
+
+    def test_exec_comp_deriv_sparsity(self):
+        # Check to make sure that when an ExecComp has more than one
+        # expression that only the partials that are needed are declared and computed
+
+        # with has_diag_partials set to the default of False and just scalars
+        p = om.Problem()
+        model = p.model
+        comp = om.ExecComp(['y1=2.0*x1+1.', 'y2=3.0*x2-1.'],x1=1.0, x2=2.0)
+        model.add_subsystem('comp', comp)
+        p.setup()
+
+        # make sure only the partials that are needed are declared
+        declared_partials = comp._declared_partials
+        self.assertListEqual( sorted([('y1', 'x1'), ('y2', 'x2') ]),
+                              sorted(declared_partials.keys()))
+
+        p.run_model()
+
+        # make sure only what is needed was computed
+        subjacs_info = comp._jacobian._subjacs_info
+        self.assertListEqual(sorted([('comp.y1', 'comp.x1'), ('comp.y2', 'comp.x2'),
+                                     ('comp.y1', 'comp.y1'),('comp.y2', 'comp.y2')]),
+                             sorted(subjacs_info.keys()))
+
+        # make sure the result of compute_partials is correct
+        J = p.compute_totals(of=['comp.y1'], wrt=['comp.x1'], return_format='array')
+        self.assertEqual(2.0, J)
+        J = p.compute_totals(of=['comp.y2'], wrt=['comp.x2'], return_format='array')
+        self.assertEqual(3.0, J)
+
+        # make sure this works with arrays and when has_diag_partials is the default of False
+        p = om.Problem()
+        model = p.model
+        comp = om.ExecComp(['y1=2.0*x1+1.', 'y2=3.0*x2-1.'],
+                           x1=np.ones(5), y1=np.ones(5), x2=np.ones(5), y2=np.ones(5))
+        model.add_subsystem('comp', comp)
+        p.setup()
+
+        declared_partials = comp._declared_partials
+        self.assertListEqual( sorted([('y1', 'x1'), ('y2', 'x2') ]),
+                              sorted(declared_partials.keys()))
+
+        p.run_model()
+        J = p.compute_totals(of=['comp.y1'], wrt=['comp.x1'], return_format='array')
+        self.assertTrue(np.all(2.0*np.identity(5) == J))
+        J = p.compute_totals(of=['comp.y2'], wrt=['comp.x2'], return_format='array')
+        self.assertTrue(np.all(3.0*np.identity(5) == J))
+
+        # with has_diag_partials True to make sure that still works with arrays
+        p = om.Problem()
+        model = p.model
+        comp = om.ExecComp(['y1=2.0*x1+1.', 'y2=3.0*x2-1.'], has_diag_partials=True,
+                           x1=np.ones(5), y1=np.ones(5), x2=np.ones(5), y2=np.ones(5) )
+        model.add_subsystem('comp', comp)
+        p.setup()
+
+        declared_partials = comp._declared_partials
+        self.assertListEqual( sorted([('y1', 'x1'), ('y2', 'x2') ]),
+                              sorted(declared_partials.keys()))
+        self.assertTrue('cols' in declared_partials[('y1', 'x1')] )
+        self.assertTrue('rows' in declared_partials[('y1', 'x1')] )
+        self.assertTrue('cols' in declared_partials[('y2', 'x2')] )
+        self.assertTrue('rows' in declared_partials[('y2', 'x2')] )
+        self.assertListEqual([0,1,2,3,4], list( comp._declared_partials[('y1','x1')]['rows']))
+        self.assertListEqual([0,1,2,3,4], list( comp._declared_partials[('y1','x1')]['cols']))
+        self.assertListEqual([0,1,2,3,4], list( comp._declared_partials[('y2','x2')]['rows']))
+        self.assertListEqual([0,1,2,3,4], list( comp._declared_partials[('y2','x2')]['cols']))
+
+        p.run_model()
+
+        J = p.compute_totals(of=['comp.y1'], wrt=['comp.x1'], return_format='array')
+        self.assertTrue(np.all(2.0*np.identity(5) == J))
+        J = p.compute_totals(of=['comp.y2'], wrt=['comp.x2'], return_format='array')
+        self.assertTrue(np.all(3.0*np.identity(5) == J))
 
     def test_has_diag_partials_shape_only(self):
         p = om.Problem()
         model = p.model
-        model.add_subsystem('indep', om.IndepVarComp('x', val=np.ones(5)))
 
         model.add_subsystem('comp', om.ExecComp('y=3.0*x + 2.5', has_diag_partials=True,
                                                 x={'shape': (5,)}, y={'shape': (5,)}))
-        model.connect('indep.x', 'comp.x')
 
         p.setup()
         p.run_model()
 
-        J = p.compute_totals(of=['comp.y'], wrt=['indep.x'], return_format='array')
+        J = p.compute_totals(of=['comp.y'], wrt=['comp.x'], return_format='array')
 
         assert_almost_equal(J, np.eye(5)*3., decimal=6)
 
     def test_tags(self):
         prob = om.Problem(model=om.Group())
-        prob.model.add_subsystem('indep', om.IndepVarComp('x', 100.0, units='cm'))
         C1 = prob.model.add_subsystem('C1', om.ExecComp('y=x+z+1.',
                                                      x={'value': 1.0, 'units': 'm', 'tags': 'tagx'},
                                                      y={'units': 'm', 'tags': ['tagy','tagq']},
                                                      z={'value': 2.0, 'tags': 'tagz'},
                                                      ))
-        prob.model.connect('indep.x', 'C1.x')
 
         prob.setup(check=False)
 
@@ -889,7 +959,6 @@ class TestExecComp(unittest.TestCase):
         outputs = prob.model.list_outputs(values=False, out_stream=None)
         self.assertEqual(sorted(outputs), [
             ('C1.y', {}),
-            ('indep.x', {}),
         ])
 
         # Outputs with tags
@@ -1011,9 +1080,7 @@ class TestExecComp(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p', om.IndepVarComp('x', np.array([1., 2., 3.])))
-        model.add_subsystem('comp', om.ExecComp('y=sum(x)', x=np.zeros((3, ))))
-        model.connect('p.x', 'comp.x')
+        model.add_subsystem('comp', om.ExecComp('y=sum(x)', x=np.array([1., 2., 3.])))
 
         prob.setup()
 
