@@ -3,6 +3,8 @@ OpenMDAO custom error: AnalysisError.
 """
 import inspect
 from openmdao.utils.general_utils import simple_warning
+from openmdao.utils.general_utils import _warn_simple_format, reset_warning_registry
+import warnings
 
 
 class AnalysisError(Exception):
@@ -13,7 +15,7 @@ class AnalysisError(Exception):
     code or a subsolver.
     """
 
-    def __init__(self, error, location=None):
+    def __init__(self, error, location=None, msginfo=None):
         """
         Initialize AnalysisError.
 
@@ -23,7 +25,13 @@ class AnalysisError(Exception):
             Error message.
         location : None or inspect.currentframe()
             inspect.currentframe of error being raised.
+        msginfo : str
+            Name of component that raise the AnalysisError.
         """
-        super(AnalysisError, self).__init__(error)
+        super().__init__(error)
         if location is not None:
-            simple_warning(f"Analysis Error: Line {location.lineno} of file {location.filename}")
+            with reset_warning_registry():
+                warnings.formatwarning = _warn_simple_format
+                msg = (f"Analysis Error: {msginfo} Line {location.lineno} of file "
+                       f"{location.filename}")
+                warnings.warn(msg, UserWarning, 2)
