@@ -3,7 +3,8 @@
 import numpy as np
 
 from openmdao.core.explicitcomponent import ExplicitComponent
-from openmdao.utils.general_utils import make_set, warn_deprecation
+from openmdao.utils.array_utils import shape_to_len
+from openmdao.utils.general_utils import make_set, warn_deprecation, ensure_compatible
 
 
 class IndepVarComp(ExplicitComponent):
@@ -25,7 +26,7 @@ class IndepVarComp(ExplicitComponent):
         **kwargs : dict
             keyword arguments.
         """
-        super(IndepVarComp, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         if 'tags' not in kwargs:
             kwargs['tags'] = {'indep_var'}
@@ -34,7 +35,7 @@ class IndepVarComp(ExplicitComponent):
 
         # A single variable is declared during instantiation
         if isinstance(name, str):
-            super(IndepVarComp, self).add_output(name, val, **kwargs)
+            super().add_output(name, val, **kwargs)
 
         elif name is None:
             pass
@@ -102,10 +103,11 @@ class IndepVarComp(ExplicitComponent):
                                "declared. They must either be declared during instantiation or "
                                "by calling add_output or add_discrete_output afterwards.")
 
-        super(IndepVarComp, self)._configure_check()
+        super()._configure_check()
 
     def add_output(self, name, val=1.0, shape=None, units=None, res_units=None, desc='',
-                   lower=None, upper=None, ref=None, ref0=None, res_ref=None, tags=None):
+                   lower=None, upper=None, ref=None, ref0=None, res_ref=None, tags=None,
+                   shape_by_conn=False, copy_shape=None):
         """
         Add an independent variable to this component.
 
@@ -138,6 +140,11 @@ class IndepVarComp(ExplicitComponent):
         tags : str or list of strs
             User defined tags that can be used to filter what gets listed when calling
             list_outputs.
+        shape_by_conn : bool
+            If True, shape this output to match its connected input(s).
+        copy_shape : str or None
+            If a str, that str is the name of a variable. Shape this output to match that of
+            the named variable.
         """
         if res_units is not None:
             warn_deprecation(f"{self.msginfo}: The 'res_units' argument was used when adding "
@@ -177,9 +184,10 @@ class IndepVarComp(ExplicitComponent):
 
         kwargs = {'shape': shape, 'units': units, 'res_units': res_units, 'desc': desc,
                   'lower': lower, 'upper': upper, 'ref': ref, 'ref0': ref0,
-                  'res_ref': res_ref, 'tags': tags
+                  'res_ref': res_ref, 'tags': tags, 'shape_by_conn': shape_by_conn,
+                  'copy_shape': copy_shape,
                   }
-        super(IndepVarComp, self).add_output(name, val, **kwargs)
+        super().add_output(name, val, **kwargs)
 
     def add_discrete_output(self, name, val, desc='', tags=None):
         """
@@ -203,7 +211,7 @@ class IndepVarComp(ExplicitComponent):
             tags = make_set(tags, name='tags') | {'indep_var'}
 
         kwargs = {'desc': desc, 'tags': tags}
-        super(IndepVarComp, self).add_discrete_output(name, val, **kwargs)
+        super().add_discrete_output(name, val, **kwargs)
 
     def _linearize(self, jac=None, sub_do_ln=False):
         """
@@ -244,7 +252,7 @@ class _AutoIndepVarComp(IndepVarComp):
         **kwargs : dict
             keyword arguments.
         """
-        super(_AutoIndepVarComp, self).__init__(name, val, **kwargs)
+        super().__init__(name, val, **kwargs)
         self._remotes = set()
 
     def _add_remote(self, name):
@@ -260,24 +268,76 @@ class _AutoIndepVarComp(IndepVarComp):
                 self.options['distributed'] = True
 
             self._remotes = all_remotes
+            for name in all_remotes:
+                self._static_var_rel2meta[name]['distributed'] = True
 
-        super(_AutoIndepVarComp, self)._set_vector_class()
+        super()._set_vector_class()
 
-    def _setup_var_data(self):
+    def add_output(self, name, val=1.0, shape=None, units=None, res_units=None, desc='',
+                   lower=None, upper=None, ref=None, ref0=None, res_ref=None, tags=None,
+                   shape_by_conn=False, copy_shape=None):
         """
-        Compute the list of abs var names, abs/prom name maps, and metadata dictionaries.
+        Add an independent variable to this component.
+
+        This should never be called by a user, as it skips all checks.
 
         Parameters
         ----------
-        recurse : bool (ignored)
-            Whether to call this method in subsystems.
+        name : str
+            name of the variable in this component's namespace.
+        val : float or list or tuple or ndarray
+            The initial value of the variable being added in user-defined units. Default is 1.0.
+        shape : int or tuple or list or None
+            Shape of this variable, only required if val is not an array.
+            Default is None.
+        units : str or None
+            Units in which the output variables will be provided to the component during execution.
+            Default is None, which means it has no units.
+        res_units : None
+            This argument is deprecated because it was unused.
+        desc : str
+            description of the variable
+        lower : None
+            This argument is deprecated because it was unused.
+        upper : None
+            This argument is deprecated because it was unused.
+        ref : None
+            This argument is deprecated because it was unused.
+        ref0 : None
+            This argument is deprecated because it was unused.
+        res_ref : None
+            This argument is deprecated because it was unused.
+        tags : str or list of strs
+            User defined tags that can be used to filter what gets listed when calling
+            list_outputs.
+        shape_by_conn : bool
+            If True, shape this output to match its connected input(s).
+        copy_shape : str or None
+            If a str, that str is the name of a variable. Shape this output to match that of
+            the named variable.
         """
-        super(_AutoIndepVarComp, self)._setup_var_data()
-        if self.comm.size > 1:
-            all_abs2meta = self._var_allprocs_abs2meta
-            abs2meta = self._var_abs2meta
+        # Add the output quickly.
+        # We don't need to check for errors because we get the value straight from a
+        # source, and ivc metadata is minimal.
+        value, shape, _ = ensure_compatible(name, val, None)
+        metadata = {
+            'value': value,
+            'shape': shape,
+            'size': shape_to_len(shape),
+            'units': units,
+            'res_units': None,
+            'desc': '',
+            'distributed': False,
+            'tags': set(),
+            'ref': 1.0,
+            'ref0': 0.0,
+            'res_ref': 1.0,
+            'lower': None,
+            'upper': None,
+            'shape_by_conn': False,
+            'copy_shape': None
+        }
 
-            for name in self._remotes:
-                if name in abs2meta:
-                    abs2meta[name]['distributed'] = True
-                all_abs2meta[name]['distributed'] = True
+        self._static_var_rel2meta[name] = metadata
+        self._static_var_rel_names['output'].append(name)
+        self._var_added(name)
