@@ -28,6 +28,7 @@ class RectangleComp(om.ExplicitComponent):
         self.add_input('width', val=1.)
         self.add_output('area', val=1.)
 
+    def setup_partials(self):
         self.declare_partials('*', '*')
 
     def compute(self, inputs, outputs):
@@ -44,6 +45,7 @@ class RectangleCompWithTags(om.ExplicitComponent):
         self.add_input('width', val=1., tags=["tag2"])
         self.add_output('area', val=1., tags=["tag1"])
 
+    def setup_partials(self):
         self.declare_partials('*', '*')
 
     def compute(self, inputs, outputs):
@@ -512,7 +514,7 @@ class ExplCompTestCase(unittest.TestCase):
             """
 
             def __init__(self, size):
-                super(ArrayAdder, self).__init__()
+                super().__init__()
                 self.size = size
 
             def setup(self):
@@ -691,7 +693,7 @@ class ExplCompTestCase(unittest.TestCase):
             """
 
             def __init__(self, size):
-                super(ArrayAdder, self).__init__()
+                super().__init__()
                 self.size = size
 
             def setup(self):
@@ -809,6 +811,7 @@ class ExplCompTestCase(unittest.TestCase):
                 self.add_input('width', val=1., tags=["tag2"])
                 self.add_output('area', val=1., tags="tag1")
 
+            def setup_partials(self):
                 self.declare_partials('*', '*')
 
             def compute(self, inputs, outputs):
@@ -867,7 +870,7 @@ class ExplCompTestCase(unittest.TestCase):
     def test_compute_inputs_read_only(self):
         class BadComp(TestExplCompSimple):
             def compute(self, inputs, outputs):
-                super(BadComp, self).compute(inputs, outputs)
+                super().compute(inputs, outputs)
                 inputs['length'] = 0.  # should not be allowed
 
         prob = om.Problem(BadComp())
@@ -877,12 +880,12 @@ class ExplCompTestCase(unittest.TestCase):
             prob.run_model()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (<model>): Attempt to set value of 'length' in input vector when it is read only.")
+                         "<model> <class BadComp>: Attempt to set value of 'length' in input vector when it is read only.")
 
     def test_compute_inputs_read_only_reset(self):
         class BadComp(TestExplCompSimple):
             def compute(self, inputs, outputs):
-                super(BadComp, self).compute(inputs, outputs)
+                super().compute(inputs, outputs)
                 raise om.AnalysisError("It's just a scratch.")
 
         prob = om.Problem(BadComp())
@@ -896,7 +899,7 @@ class ExplCompTestCase(unittest.TestCase):
     def test_compute_partials_inputs_read_only(self):
         class BadComp(TestExplCompSimpleDense):
             def compute_partials(self, inputs, partials):
-                super(BadComp, self).compute_partials(inputs, partials)
+                super().compute_partials(inputs, partials)
                 inputs['length'] = 0.  # should not be allowed
 
         prob = om.Problem(BadComp())
@@ -907,13 +910,13 @@ class ExplCompTestCase(unittest.TestCase):
             prob.check_partials()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (<model>): Attempt to set value of 'length' in input vector "
+                         "<model> <class BadComp>: Attempt to set value of 'length' in input vector "
                          "when it is read only.")
 
     def test_compute_partials_inputs_read_only_reset(self):
         class BadComp(TestExplCompSimpleDense):
             def compute_partials(self, inputs, partials):
-                super(BadComp, self).compute_partials(inputs, partials)
+                super().compute_partials(inputs, partials)
                 raise om.AnalysisError("It's just a scratch.")
 
         prob = om.Problem(BadComp())
@@ -929,7 +932,7 @@ class ExplCompTestCase(unittest.TestCase):
     def test_compute_jacvec_product_inputs_read_only(self):
         class BadComp(RectangleJacVec):
             def compute_jacvec_product(self, inputs, d_inputs, d_outputs, mode):
-                super(BadComp, self).compute_jacvec_product(inputs, d_inputs, d_outputs, mode)
+                super().compute_jacvec_product(inputs, d_inputs, d_outputs, mode)
                 inputs['length'] = 0.  # should not be allowed
 
         prob = om.Problem(BadComp())
@@ -940,13 +943,13 @@ class ExplCompTestCase(unittest.TestCase):
             prob.check_partials()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (<model>): Attempt to set value of 'length' in input vector "
+                         "<model> <class BadComp>: Attempt to set value of 'length' in input vector "
                          "when it is read only.")
 
     def test_compute_jacvec_product_inputs_read_only_reset(self):
         class BadComp(RectangleJacVec):
             def compute_jacvec_product(self, inputs, d_inputs, d_outputs, mode):
-                super(BadComp, self).compute_jacvec_product(inputs, d_inputs, d_outputs, mode)
+                super().compute_jacvec_product(inputs, d_inputs, d_outputs, mode)
                 raise om.AnalysisError("It's just a scratch.")
 
         prob = om.Problem(BadComp())
