@@ -27,6 +27,7 @@ class QuadraticComp(om.ImplicitComponent):
         self.add_input('c', val=1.)
         self.add_output('x', val=0., tags=['tag_x'])
 
+    def setup_partials(self):
         self.declare_partials(of='*', wrt='*')
 
     def apply_nonlinear(self, inputs, outputs, residuals):
@@ -803,7 +804,7 @@ class ImplicitCompGuessTestCase(unittest.TestCase):
             prob.run_model()
 
         self.assertEqual(str(cm.exception),
-                         "ImpWithInitial (comp1): Attempt to set value of 'x' in input vector "
+                         "'comp1' <class ImpWithInitial>: Attempt to set value of 'x' in input vector "
                          "when it is read only.")
 
     def test_guess_nonlinear_inputs_read_only_reset(self):
@@ -867,7 +868,7 @@ class ImplicitCompGuessTestCase(unittest.TestCase):
             prob.run_model()
 
         self.assertEqual(str(cm.exception),
-                         "ImpWithInitial (comp1): Attempt to set value of 'y' in residual vector "
+                         "'comp1' <class ImpWithInitial>: Attempt to set value of 'y' in residual vector "
                          "when it is read only.")
 
 
@@ -876,7 +877,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
     def test_apply_nonlinear_inputs_read_only(self):
         class BadComp(QuadraticComp):
             def apply_nonlinear(self, inputs, outputs, residuals):
-                super(BadComp, self).apply_nonlinear(inputs, outputs, residuals)
+                super().apply_nonlinear(inputs, outputs, residuals)
                 inputs['a'] = 0.  # should not be allowed
 
         prob = om.Problem()
@@ -889,13 +890,13 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_nonlinear()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (bad): Attempt to set value of 'a' in input vector "
+                         "'bad' <class BadComp>: Attempt to set value of 'a' in input vector "
                          "when it is read only.")
 
     def test_apply_nonlinear_outputs_read_only(self):
         class BadComp(QuadraticComp):
             def apply_nonlinear(self, inputs, outputs, residuals):
-                super(BadComp, self).apply_nonlinear(inputs, outputs, residuals)
+                super().apply_nonlinear(inputs, outputs, residuals)
                 outputs['x'] = 0.  # should not be allowed
 
         prob = om.Problem()
@@ -908,13 +909,13 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_nonlinear()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (bad): Attempt to set value of 'x' in output vector "
+                         "'bad' <class BadComp>: Attempt to set value of 'x' in output vector "
                          "when it is read only.")
 
     def test_apply_nonlinear_read_only_reset(self):
         class BadComp(QuadraticComp):
             def apply_nonlinear(self, inputs, outputs, residuals):
-                super(BadComp, self).apply_nonlinear(inputs, outputs, residuals)
+                super().apply_nonlinear(inputs, outputs, residuals)
                 raise om.AnalysisError("It's just a scratch.")
 
         prob = om.Problem()
@@ -932,7 +933,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
     def test_solve_nonlinear_inputs_read_only(self):
         class BadComp(QuadraticComp):
             def solve_nonlinear(self, inputs, outputs):
-                super(BadComp, self).solve_nonlinear(inputs, outputs)
+                super().solve_nonlinear(inputs, outputs)
                 inputs['a'] = 0.  # should not be allowed
 
         prob = om.Problem()
@@ -944,13 +945,13 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.run_model()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (bad): Attempt to set value of 'a' in input vector "
+                         "'bad' <class BadComp>: Attempt to set value of 'a' in input vector "
                          "when it is read only.")
 
     def test_solve_nonlinear_inputs_read_only_reset(self):
         class BadComp(QuadraticComp):
             def solve_nonlinear(self, inputs, outputs):
-                super(BadComp, self).solve_nonlinear(inputs, outputs)
+                super().solve_nonlinear(inputs, outputs)
                 raise om.AnalysisError("It's just a scratch.")
 
         prob = om.Problem()
@@ -966,7 +967,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
     def test_linearize_inputs_read_only(self):
         class BadComp(QuadraticLinearize):
             def linearize(self, inputs, outputs, partials):
-                super(BadComp, self).linearize(inputs, outputs, partials)
+                super().linearize(inputs, outputs, partials)
                 inputs['a'] = 0.  # should not be allowed
 
         prob = om.Problem()
@@ -979,13 +980,13 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_linearize()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (bad): Attempt to set value of 'a' in input vector "
+                         "'bad' <class BadComp>: Attempt to set value of 'a' in input vector "
                          "when it is read only.")
 
     def test_linearize_outputs_read_only(self):
         class BadComp(QuadraticLinearize):
             def linearize(self, inputs, outputs, partials):
-                super(BadComp, self).linearize(inputs, outputs, partials)
+                super().linearize(inputs, outputs, partials)
                 outputs['x'] = 0.  # should not be allowed
 
         prob = om.Problem()
@@ -998,13 +999,13 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_linearize()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (bad): Attempt to set value of 'x' in output vector "
+                         "'bad' <class BadComp>: Attempt to set value of 'x' in output vector "
                          "when it is read only.")
 
     def test_linearize_read_only_reset(self):
         class BadComp(QuadraticLinearize):
             def linearize(self, inputs, outputs, partials):
-                super(BadComp, self).linearize(inputs, outputs, partials)
+                super().linearize(inputs, outputs, partials)
                 raise om.AnalysisError("It's just a scratch.")
 
         prob = om.Problem()
@@ -1022,7 +1023,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
     def test_apply_linear_inputs_read_only(self):
         class BadComp(QuadraticJacVec):
             def apply_linear(self, inputs, outputs, d_inputs, d_outputs, d_residuals, mode):
-                super(BadComp, self).apply_linear(inputs, outputs,
+                super().apply_linear(inputs, outputs,
                                                   d_inputs, d_outputs, d_residuals, mode)
                 inputs['a'] = 0.  # should not be allowed
 
@@ -1036,13 +1037,13 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_linear(['linear'], 'fwd')
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (bad): Attempt to set value of 'a' in input vector "
+                         "'bad' <class BadComp>: Attempt to set value of 'a' in input vector "
                          "when it is read only.")
 
     def test_apply_linear_outputs_read_only(self):
         class BadComp(QuadraticJacVec):
             def apply_linear(self, inputs, outputs, d_inputs, d_outputs, d_residuals, mode):
-                super(BadComp, self).apply_linear(inputs, outputs,
+                super().apply_linear(inputs, outputs,
                                                   d_inputs, d_outputs, d_residuals, mode)
                 outputs['x'] = 0.  # should not be allowed
 
@@ -1056,13 +1057,13 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_linear(['linear'], 'fwd')
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (bad): Attempt to set value of 'x' in output vector "
+                         "'bad' <class BadComp>: Attempt to set value of 'x' in output vector "
                          "when it is read only.")
 
     def test_apply_linear_dinputs_read_only(self):
         class BadComp(QuadraticJacVec):
             def apply_linear(self, inputs, outputs, d_inputs, d_outputs, d_residuals, mode):
-                super(BadComp, self).apply_linear(inputs, outputs,
+                super().apply_linear(inputs, outputs,
                                                   d_inputs, d_outputs, d_residuals, mode)
                 d_inputs['a'] = 0.  # should not be allowed
 
@@ -1076,13 +1077,13 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_linear(['linear'], 'fwd')
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (bad): Attempt to set value of 'a' in input vector "
+                         "'bad' <class BadComp>: Attempt to set value of 'a' in input vector "
                          "when it is read only.")
 
     def test_apply_linear_doutputs_read_only(self):
         class BadComp(QuadraticJacVec):
             def apply_linear(self, inputs, outputs, d_inputs, d_outputs, d_residuals, mode):
-                super(BadComp, self).apply_linear(inputs, outputs,
+                super().apply_linear(inputs, outputs,
                                                   d_inputs, d_outputs, d_residuals, mode)
                 d_outputs['x'] = 0.  # should not be allowed
 
@@ -1096,13 +1097,13 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_linear(['linear'], 'fwd')
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (bad): Attempt to set value of 'x' in output vector "
+                         "'bad' <class BadComp>: Attempt to set value of 'x' in output vector "
                          "when it is read only.")
 
     def test_apply_linear_dresids_read_only(self):
         class BadComp(QuadraticJacVec):
             def apply_linear(self, inputs, outputs, d_inputs, d_outputs, d_residuals, mode):
-                super(BadComp, self).apply_linear(inputs, outputs,
+                super().apply_linear(inputs, outputs,
                                                   d_inputs, d_outputs, d_residuals, mode)
                 d_residuals['x'] = 0.  # should not be allowed
 
@@ -1116,13 +1117,13 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_apply_linear(['linear'], 'rev')
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (bad): Attempt to set value of 'x' in residual vector "
+                         "'bad' <class BadComp>: Attempt to set value of 'x' in residual vector "
                          "when it is read only.")
 
     def test_apply_linear_read_only_reset(self):
         class BadComp(QuadraticJacVec):
             def apply_linear(self, inputs, outputs, d_inputs, d_outputs, d_residuals, mode):
-                super(BadComp, self).apply_linear(inputs, outputs,
+                super().apply_linear(inputs, outputs,
                                                   d_inputs, d_outputs, d_residuals, mode)
                 raise om.AnalysisError("It's just a scratch.")
 
@@ -1142,7 +1143,7 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
     def test_solve_linear_doutputs_read_only(self):
         class BadComp(QuadraticJacVec):
             def solve_linear(self, d_outputs, d_residuals, mode):
-                super(BadComp, self).solve_linear(d_outputs, d_residuals, mode)
+                super().solve_linear(d_outputs, d_residuals, mode)
                 d_outputs['x'] = 0.  # should not be allowed
 
         prob = om.Problem()
@@ -1156,13 +1157,13 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_solve_linear(['linear'], 'rev')
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (bad): Attempt to set value of 'x' in output vector "
+                         "'bad' <class BadComp>: Attempt to set value of 'x' in output vector "
                          "when it is read only.")
 
     def test_solve_linear_dresids_read_only(self):
         class BadComp(QuadraticJacVec):
             def solve_linear(self, d_outputs, d_residuals, mode):
-                super(BadComp, self).solve_linear(d_outputs, d_residuals, mode)
+                super().solve_linear(d_outputs, d_residuals, mode)
                 d_residuals['x'] = 0.  # should not be allowed
 
         prob = om.Problem()
@@ -1176,13 +1177,13 @@ class ImplicitCompReadOnlyTestCase(unittest.TestCase):
             prob.model.run_solve_linear(['linear'], 'fwd')
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (bad): Attempt to set value of 'x' in residual vector "
+                         "'bad' <class BadComp>: Attempt to set value of 'x' in residual vector "
                          "when it is read only.")
 
     def test_solve_linear_read_only_reset(self):
         class BadComp(QuadraticJacVec):
             def solve_linear(self, d_outputs, d_residuals, mode):
-                super(BadComp, self).solve_linear(d_outputs, d_residuals, mode)
+                super().solve_linear(d_outputs, d_residuals, mode)
                 raise om.AnalysisError("It's just a scratch.")
 
         prob = om.Problem()
@@ -1300,6 +1301,7 @@ class ListFeatureTestCase(unittest.TestCase):
                                 ref=1.1, ref0=2.1,
                                 units='inch')
 
+            def setup_partials(self):
                 self.declare_partials(of='*', wrt='*')
 
             def apply_nonlinear(self, inputs, outputs, residuals):
