@@ -22,6 +22,7 @@ class QuadraticCompVectorized(om.ImplicitComponent):
         self.add_input('c', val=np.array([-1.0, -2.0, -3.0]))
         self.add_output('x', val=np.array([.5, .5, .5]))
 
+    def setup_partials(self):
         self.declare_partials(of='*', wrt='*')
 
     def apply_nonlinear(self, inputs, outputs, residuals):
@@ -82,7 +83,7 @@ class QCVProblem(om.Problem):
     """
 
     def __init__(self, comp_class=QuadraticCompVectorized):
-        super(QCVProblem, self).__init__()
+        super().__init__()
 
         model = self.model
 
@@ -114,6 +115,7 @@ class RectangleCompVectorized(om.ExplicitComponent):
         self.add_input('width', val=np.array([1.0, 2.0, 3.0]))
         self.add_output('area', shape=(3, ))
 
+    def setup_partials(self):
         self.declare_partials('*', '*')
 
     def compute(self, inputs, outputs):
@@ -701,7 +703,7 @@ class MatMatTestCase(unittest.TestCase):
             prob.compute_totals()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (comp): Attempt to set value of 'a' in input vector "
+                         "'comp' <class BadComp>: Attempt to set value of 'a' in input vector "
                          "when it is read only.")
 
     def test_apply_multi_linear_outputs_read_only(self):
@@ -720,7 +722,7 @@ class MatMatTestCase(unittest.TestCase):
             prob.compute_totals()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (comp): Attempt to set value of 'x' in output vector "
+                         "'comp' <class BadComp>: Attempt to set value of 'x' in output vector "
                          "when it is read only.")
 
     def test_apply_multi_linear_dinputs_read_only(self):
@@ -739,7 +741,7 @@ class MatMatTestCase(unittest.TestCase):
             prob.compute_totals()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (comp): Attempt to set value of 'a' in input vector "
+                         "'comp' <class BadComp>: Attempt to set value of 'a' in input vector "
                          "when it is read only.")
 
     def test_apply_multi_linear_doutputs_read_only(self):
@@ -758,7 +760,7 @@ class MatMatTestCase(unittest.TestCase):
             prob.compute_totals()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (comp): Attempt to set value of 'x' in output vector "
+                         "'comp' <class BadComp>: Attempt to set value of 'x' in output vector "
                          "when it is read only.")
 
     def test_apply_multi_linear_dresids_read_only(self):
@@ -777,14 +779,14 @@ class MatMatTestCase(unittest.TestCase):
             prob.compute_totals()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (comp): Attempt to set value of 'x' in residual vector "
+                         "'comp' <class BadComp>: Attempt to set value of 'x' in residual vector "
                          "when it is read only.")
 
 
 class JacVec(om.ExplicitComponent):
 
     def __init__(self, size):
-        super(JacVec, self).__init__()
+        super().__init__()
         self.size = size
 
     def setup(self):
@@ -921,7 +923,7 @@ class ComputeMultiJacVecTestCase(unittest.TestCase):
             p.compute_totals()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (comp): Attempt to set value of 'x' in input vector "
+                         "'comp' <class BadComp>: Attempt to set value of 'x' in input vector "
                          "when it is read only.")
 
         p = self.setup_model(size=5, comp_class=BadComp, vectorize=True, mode='rev')
@@ -930,7 +932,7 @@ class ComputeMultiJacVecTestCase(unittest.TestCase):
             p.compute_totals()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (comp): Attempt to set value of 'f_xy' in residual vector "
+                         "'comp' <class BadComp>: Attempt to set value of 'f_xy' in residual vector "
                          "when it is read only.")
 
     def test_compute_jacvec_product_inputs_read_only(self):
@@ -945,7 +947,7 @@ class ComputeMultiJacVecTestCase(unittest.TestCase):
             p.compute_totals()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (comp): Attempt to set value of 'x' in input vector "
+                         "'comp' <class BadComp>: Attempt to set value of 'x' in input vector "
                          "when it is read only.")
 
     def test_compute_multi_jacvec_product_mode_read_only(self):
@@ -970,7 +972,7 @@ class ComputeMultiJacVecTestCase(unittest.TestCase):
             p.compute_totals()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (comp): Attempt to set value of 'x' in input vector "
+                         "'comp' <class BadComp>: Attempt to set value of 'x' in input vector "
                          "when it is read only.")
 
         p = self.setup_model(size=5, comp_class=BadComp, vectorize=True, mode='rev')
@@ -979,7 +981,7 @@ class ComputeMultiJacVecTestCase(unittest.TestCase):
             p.compute_totals()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (comp): Attempt to set value of 'f_xy' in residual vector "
+                         "'comp' <class BadComp>: Attempt to set value of 'f_xy' in residual vector "
                          "when it is read only.")
 
     def test_compute_multi_jacvec_product_inputs_read_only(self):
@@ -994,7 +996,7 @@ class ComputeMultiJacVecTestCase(unittest.TestCase):
             p.compute_totals()
 
         self.assertEqual(str(cm.exception),
-                         "BadComp (comp): Attempt to set value of 'x' in input vector "
+                         "'comp' <class BadComp>: Attempt to set value of 'x' in input vector "
                          "when it is read only.")
 
 
