@@ -66,6 +66,11 @@ CITATIONS = """@article{Hwang_maud_2018
 }
 """
 
+try:
+    DEFAULT_SIGNAL = signal.SIGUSR1
+except AttributeError:
+    DEFAULT_SIGNAL = None
+
 
 class UserRequestedException(Exception):
     """
@@ -137,7 +142,7 @@ class pyOptSparseDriver(Driver):
         if Optimization is None:
             raise RuntimeError('pyOptSparseDriver is not available, pyOptsparse is not installed.')
 
-        super(pyOptSparseDriver, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         # What we support
         self.supports['inequality_constraints'] = True
@@ -151,6 +156,7 @@ class pyOptSparseDriver(Driver):
         # What we don't support yet
         self.supports['active_set'] = False
         self.supports['integer_design_vars'] = False
+        self.supports['distributed_design_vars'] = False
         self.supports._read_only = True
 
         # The user places optimizer-specific settings in here.
@@ -188,7 +194,7 @@ class pyOptSparseDriver(Driver):
         self.options.declare('gradient method', default='openmdao',
                              values={'openmdao', 'pyopt_fd', 'snopt_fd'},
                              desc='Finite difference implementation to use')
-        self.options.declare('user_terminate_signal', default=signal.SIGUSR1, allow_none=True,
+        self.options.declare('user_terminate_signal', default=DEFAULT_SIGNAL, allow_none=True,
                              desc='OS signal that triggers a clean user-termination. Only SNOPT'
                              'supports this option.')
 
@@ -210,7 +216,7 @@ class pyOptSparseDriver(Driver):
         problem : <Problem>
             Pointer to the containing problem.
         """
-        super(pyOptSparseDriver, self)._setup_driver(problem)
+        super()._setup_driver(problem)
 
         self.supports._read_only = False
         self.supports['gradients'] = self.options['optimizer'] in grad_drivers
