@@ -55,20 +55,18 @@ class TestNonlinearRunOnceSolver(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', om.IndepVarComp('x', 0.0), promotes=['x'])
-        model.add_subsystem('p2', om.IndepVarComp('y', 0.0), promotes=['y'])
         model.add_subsystem('comp', Paraboloid(), promotes=['x', 'y', 'f_xy'])
 
         model.nonlinear_solver = om.NonlinearRunOnce()
 
         prob.setup(check=False, mode='fwd')
 
-        prob['x'] = 4.0
-        prob['y'] = 6.0
+        prob.set_val('x', 4.0)
+        prob.set_val('y', 6.0)
 
         prob.run_model()
 
-        assert_near_equal(prob['f_xy'], 122.0)
+        assert_near_equal(prob.get_val('f_xy'), 122.0)
 
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
