@@ -92,6 +92,7 @@ def get_logger(name='default_logger', level=logging.INFO, use_format=False,
     else:
         # create new logger
         logger = logging.getLogger(name)
+        logger.setLevel(level)
         if out_stream:
             _set_handler(logger, logging.StreamHandler(out_stream), level, use_format)
         if out_file:
@@ -205,3 +206,21 @@ class TestLogger(object):
                 return True
 
         return False
+
+    def find_in(self, typ, message):
+        """
+        Find the given message among the stored messages.
+
+        Raises an exception if the given message isn't found.
+
+        Parameters
+        ----------
+        typ : str
+            Type of messages ('error', 'warning', 'info') to be searched.
+
+        message : str
+            The message to match.
+        """
+        if not self.contains(typ, message):
+            raise RuntimeError('Message "{}" not found in {}.'.format(message,
+                                                                      ',\n'.join(self._msgs[typ])))
