@@ -43,16 +43,16 @@ class DefaultTransfer(Transfer):
             subsys._setup_transfers()
 
         abs2meta = group._var_abs2meta
-        allprocs_abs2meta = group._var_allprocs_abs2meta
+        allprocs_abs2meta_out = group._var_allprocs_abs2meta['output']
 
         group._transfers = transfers = {}
         vectors = group._vectors
         offsets = _global2local_offsets(group._get_var_offsets())
 
         vec_names = group._lin_rel_vec_name_list if group._use_derivatives else group._vec_names
+        allsubs = group._subsystems_allprocs
 
         mypathlen = len(group.pathname + '.' if group.pathname else '')
-        sub_inds = group._subsystems_inds
 
         for vec_name in vec_names:
             relvars, _ = group._relevant[vec_name]['@all']
@@ -60,14 +60,14 @@ class DefaultTransfer(Transfer):
             relvars_out = relvars['output']
 
             # Initialize empty lists for the transfer indices
-            nsub_allprocs = len(group._subsystems_allprocs)
+            nsub_allprocs = len(allsubs)
             xfer_in = []
             xfer_out = []
-            fwd_xfer_in = [[] for s in group._subsystems_allprocs]
-            fwd_xfer_out = [[] for s in group._subsystems_allprocs]
+            fwd_xfer_in = defaultdict(list)
+            fwd_xfer_out = defaultdict(list)
             if rev:
-                rev_xfer_in = [[] for s in group._subsystems_allprocs]
-                rev_xfer_out = [[] for s in group._subsystems_allprocs]
+                rev_xfer_in = defaultdict(list)
+                rev_xfer_out = defaultdict(list)
 
             allprocs_abs2idx = group._var_allprocs_abs2idx[vec_name]
             sizes_in = group._var_sizes[vec_name]['input']
@@ -81,12 +81,12 @@ class DefaultTransfer(Transfer):
                     continue
 
                 # Only continue if the input exists on this processor
-                if abs_in in abs2meta:
+                if abs_in in abs2meta['input']:
 
                     indices = None
                     # Get meta
-                    meta_in = abs2meta[abs_in]
-                    meta_out = allprocs_abs2meta[abs_out]
+                    meta_in = abs2meta['input'][abs_in]
+                    meta_out = allprocs_abs2meta_out[abs_out]
 
                     idx_in = allprocs_abs2idx[abs_in]
                     idx_out = allprocs_abs2idx[abs_out]
@@ -113,33 +113,32 @@ class DefaultTransfer(Transfer):
 
                     # Now the indices are ready - input_inds, output_inds
                     sub_in = abs_in[mypathlen:].split('.', 1)[0]
-                    isub = sub_inds[sub_in]
-                    fwd_xfer_in[isub].append(input_inds)
-                    fwd_xfer_out[isub].append(output_inds)
-                    if rev and abs_out in abs2meta:
+                    fwd_xfer_in[sub_in].append(input_inds)
+                    fwd_xfer_out[sub_in].append(output_inds)
+                    if rev and abs_out in abs2meta['output']:
                         sub_out = abs_out[mypathlen:].split('.', 1)[0]
-                        isub = sub_inds[sub_out]
-                        rev_xfer_in[isub].append(input_inds)
-                        rev_xfer_out[isub].append(output_inds)
+                        rev_xfer_in[sub_out].append(input_inds)
+                        rev_xfer_out[sub_out].append(output_inds)
 
             tot_size = 0
-            for isub in range(nsub_allprocs):
-                fwd_xfer_in[isub] = _merge(fwd_xfer_in[isub])
-                fwd_xfer_out[isub] = _merge(fwd_xfer_out[isub])
-                tot_size += fwd_xfer_in[isub].size
-                if rev:
-                    rev_xfer_in[isub] = _merge(rev_xfer_in[isub])
-                    rev_xfer_out[isub] = _merge(rev_xfer_out[isub])
+            for sname, inds in fwd_xfer_in.items():
+                fwd_xfer_in[sname] = arr = _merge(inds)
+                fwd_xfer_out[sname] = _merge(fwd_xfer_out[sname])
+                tot_size += arr.size
+
+            if rev:
+                for sname, inds in rev_xfer_in.items():
+                    rev_xfer_in[sname] = _merge(inds)
+                    rev_xfer_out[sname] = _merge(rev_xfer_out[sname])
 
             transfers[vec_name] = {}
 
             if tot_size > 0:
                 try:
-                    xfer_in = np.concatenate(fwd_xfer_in)
-                    xfer_out = np.concatenate(fwd_xfer_out)
+                    xfer_in = np.concatenate(list(fwd_xfer_in.values()))
+                    xfer_out = np.concatenate(list(fwd_xfer_out.values()))
                 except ValueError:
-                    xfer_in = fwd_xfer_in
-                    xfer_out = fwd_xfer_out
+                    xfer_in = xfer_out = np.zeros(0, dtype=INT_DTYPE)
 
                 out_vec = vectors['output'][vec_name]
 
@@ -147,23 +146,29 @@ class DefaultTransfer(Transfer):
                                            xfer_in, xfer_out, group.comm)
             else:
                 xfer_all = None
-            transfers[vec_name]['fwd', None] = xfer_all
+
+            transfers[vec_name]['fwd'] = xfwd = {}
+            xfwd[None] = xfer_all
             if rev:
-                transfers[vec_name]['rev', None] = xfer_all
-            for isub in range(nsub_allprocs):
-                if fwd_xfer_in[isub].size > 0:
-                    transfers[vec_name]['fwd', isub] = DefaultTransfer(
-                        vectors['input'][vec_name], vectors['output'][vec_name],
-                        fwd_xfer_in[isub], fwd_xfer_out[isub], group.comm)
+                transfers[vec_name]['rev'] = xrev = {}
+                xrev[None] = xfer_all
+
+            for sname, inds in fwd_xfer_in.items():
+                if inds.size > 0:
+                    xfwd[sname] = DefaultTransfer(vectors['input'][vec_name],
+                                                  vectors['output'][vec_name],
+                                                  inds, fwd_xfer_out[sname], group.comm)
                 else:
-                    transfers[vec_name]['fwd', isub] = None
-                if rev:
-                    if rev_xfer_out[isub].size > 0:
-                        transfers[vec_name]['rev', isub] = DefaultTransfer(
-                            vectors['input'][vec_name], vectors['output'][vec_name],
-                            rev_xfer_in[isub], rev_xfer_out[isub], group.comm)
+                    xfwd[sname] = None
+
+            if rev:
+                for sname, inds in rev_xfer_out.items():
+                    if inds.size > 0:
+                        xrev[sname] = DefaultTransfer(vectors['input'][vec_name],
+                                                      vectors['output'][vec_name],
+                                                      rev_xfer_in[sname], inds, group.comm)
                     else:
-                        transfers[vec_name]['rev', isub] = None
+                        xrev[sname] = None
 
         if group._use_derivatives:
             transfers['nonlinear'] = transfers['linear']
