@@ -119,7 +119,7 @@ class DefaultVector(Vector):
         _views_flat
         """
         system = self._system()
-        type_ = self._typ
+        io = self._typ
         kind = self._kind
         ncol = self._ncol
 
@@ -135,9 +135,9 @@ class DefaultVector(Vector):
         self._cplx_views = cplx_views = {}
         self._cplx_views_flat = cplx_views_flat = {}
 
-        abs2meta = system._var_abs2meta
+        abs2meta = system._var_abs2meta[io]
         start = end = 0
-        for abs_name in system._var_relevant_names[self._name][type_]:
+        for abs_name in system._var_relevant_names[self._name][io]:
             meta = abs2meta[abs_name]
             end = start + meta['size']
             shape = meta['shape']
