@@ -52,10 +52,9 @@ class TestVector(unittest.TestCase):
         p.setup()
         p.final_setup()
 
-        new_vec = p.model._outputs._clone()
-        new_vec.set_const(3.)
+        p.model._residuals.set_val(3.)
 
-        self.assertEqual(new_vec.dot(p.model._outputs), 9.)
+        self.assertEqual(p.model._residuals.dot(p.model._outputs), 9.)
 
 
 A = np.array([[1.0, 8.0, 0.0], [-1.0, 10.0, 2.0], [3.0, 100.5, 1.0]])
@@ -155,9 +154,9 @@ class TestPETScVector2Proc(unittest.TestCase):
         assert_near_equal(norm_val, 0.22595230821097395, 1e-10)
 
         # test petsc dot while we're at it
-        vec.set_const(3.)
+        vec.set_val(3.)
         vec2 = prob.model._vectors['residual']['linear']
-        vec2.set_const(4.)
+        vec2.set_val(4.)
         assert_near_equal(vec.dot(vec2), 12.*6, 1e-10)
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
@@ -187,9 +186,9 @@ class TestPETScVector3Proc(unittest.TestCase):
         assert_near_equal(norm_val, 0.22595230821097395, 1e-10)
 
         # test petsc dot while we're at it
-        vec.set_const(3.)
+        vec.set_val(3.)
         vec2 = prob.model._vectors['residual']['linear']
-        vec2.set_const(4.)
+        vec2.set_val(4.)
         assert_near_equal(vec.dot(vec2), 12.*6, 1e-10)
 
     def test_distributed_norm_parallel_group(self):
@@ -227,9 +226,9 @@ class TestPETScVector3Proc(unittest.TestCase):
         assert_near_equal(norm_val, 8.888194417315589, 1e-10)
 
         # test petsc dot while we're at it
-        vec.set_const(3.)
+        vec.set_val(3.)
         vec2 = prob.model._vectors['residual']['linear']
-        vec2.set_const(4.)
+        vec2.set_val(4.)
         assert_near_equal(vec.dot(vec2), 12.*13, 1e-10)
 
 
