@@ -241,7 +241,7 @@ class Vector(object):
         path = system.pathname
         idx = len(path) + 1 if path else 0
 
-        return (n[idx:] for n in system._var_abs_names[self._typ] if n in self._names)
+        return (n[idx:] for n in system._var_abs2meta[self._typ] if n in self._names)
 
     def _abs_item_iter(self, flat=True):
         """
