@@ -192,7 +192,7 @@ n2_gui_test_scripts = {
             "desc": "Check the number of cells in the N2 Matrix",
             "test": "count",
             "selector": "g#n2elements > g.n2cell",
-            "count": 11
+            "count": 14
         },
         {
             "desc": "Hover on N2 matrix element and check arrow count",
@@ -209,7 +209,7 @@ n2_gui_test_scripts = {
         {
             "desc": "Hover on N2 matrix element and check arrow count",
             "test": "hoverArrow",
-            "selector": "g#n2elements rect#cellShape_node_10.vMid",
+            "selector": "g#n2elements rect#cellShape_node_13.vMid",
             "arrowCount": 2
         },
         {
@@ -224,7 +224,7 @@ n2_gui_test_scripts = {
         {
             "desc": "Hover over collapsed N2 matrix element and check arrow count",
             "test": "hoverArrow",
-            "selector": "g#n2elements rect#cellShape_node_9.gMid",
+            "selector": "g#n2elements rect#cellShape_node_12.gMid",
             "arrowCount": 1
         },
         {
@@ -242,7 +242,7 @@ n2_gui_test_scripts = {
         {
             "desc": "Hover over zoomed N2 cell and check arrow count",
             "test": "hoverArrow",
-            "selector": "g#n2elements rect#cellShape_node_10.vMid",
+            "selector": "g#n2elements rect#cellShape_node_13.vMid",
             "arrowCount": 2
         },
         {
@@ -257,7 +257,7 @@ n2_gui_test_scripts = {
         {
             "desc": "Hover over collapsed N2 cell and check arrow count",
             "test": "hoverArrow",
-            "selector": "g#n2elements rect#cellShape_node_9.gMid",
+            "selector": "g#n2elements rect#cellShape_node_12.gMid",
             "arrowCount": 1
         },
         {
@@ -271,19 +271,19 @@ n2_gui_test_scripts = {
         {
             "desc": "Hover on N2 matrix element and check arrow count",
             "test": "hoverArrow",
-            "selector": "g#n2elements rect#cellShape_node_10.vMid",
+            "selector": "g#n2elements rect#cellShape_node_9.vMid",
             "arrowCount": 4
         },
         {
             "desc": "Left-click on partition tree element to zoom",
             "test": "click",
-            "selector": "g#tree rect#g1_d2_y2",
+            "selector": "g#tree rect#g1_d2",
             "button": "left"
         },
         {
             "desc": "Hover on N2 matrix element and check arrow count",
             "test": "hoverArrow",
-            "selector": "g#n2elements rect#cellShape_node_10.vMid",
+            "selector": "g#n2elements rect#cellShape_node_13.vMid",
             "arrowCount": 4
         },
         {
@@ -298,8 +298,8 @@ n2_gui_test_scripts = {
         {
             "desc": "Hover over collapsed N2 matrix element and check arrow count",
             "test": "hoverArrow",
-            "selector": "g#n2elements rect#cellShape_node_12.gMid",
-            "arrowCount": 3
+            "selector": "g#n2elements rect#cellShape_node_15.gMid",
+            "arrowCount": 4
         },
         {
             "desc": "Right-click on partition tree element to uncollapse",
@@ -316,7 +316,7 @@ n2_gui_test_scripts = {
         {
             "desc": "Hover over zoomed N2 cell and check arrow count",
             "test": "hoverArrow",
-            "selector": "g#n2elements rect#cellShape_node_20.vMid",
+            "selector": "g#n2elements rect#cellShape_node_23.vMid",
             "arrowCount": 4
         },
         {
@@ -331,8 +331,8 @@ n2_gui_test_scripts = {
         {
             "desc": "Hover over collapsed N2 cell and check arrow count",
             "test": "hoverArrow",
-            "selector": "g#n2elements rect#cellShape_node_2.gMid",
-            "arrowCount": 3
+            "selector": "g#n2elements rect#cellShape_node_5.gMid",
+            "arrowCount": 4
         },
         {
             "desc": "Right-click again on solver element to uncollapse",
@@ -349,7 +349,7 @@ n2_gui_test_scripts = {
         {
             "desc": "Hover over N2 cell and check arrow count with collapsed group",
             "test": "hoverArrow",
-            "selector": "g#n2elements rect#cellShape_node_14.vMid",
+            "selector": "g#n2elements rect#cellShape_node_17.vMid",
             "arrowCount": 2
         },
     ],
@@ -390,7 +390,8 @@ n2_gui_test_scripts = {
             "selector": "rect#indeps",
             "n2ElementCount": 2
         }
-    ]
+    ],
+    "nan_value": []
 }
 
 n2_gui_test_models = n2_gui_test_scripts.keys()
@@ -401,14 +402,23 @@ class n2_gui_test_case(unittest.TestCase):
     async def handle_console_err(self, msg):
         """ Invoked any time that an error or warning appears in the log. """
         if msg.type == 'warning':
-            print("Warning: " + self.current_test_desc + "\n" + msg.text + "\n")
+            self.console_warning = True
+            print('    Console Warning: ' + msg.text)
         elif msg.type == 'error':
-            self.fail(msg.text)
+            self.console_error = True
+            print('    Console Error: ' + msg.text)
+
+    async def handle_page_err(self, msg):
+        self.page_error = True
+        print('    Error on page: ', msg)
+
+    def setup_error_handlers(self):
+        self.console_warning = False
+        self.console_error = False
+        self.page_error = False
 
-    async def setup_error_handlers(self):
         self.page.on('console', lambda msg: self.handle_console_err(msg))
-        self.page.on('pageerror', lambda msg: self.fail(msg))
-#        self.page.on('requestfailed', lambda msg: self.fail(msg))
+        self.page.on('pageerror', lambda msg: self.handle_page_err(msg))
 
     async def setup_browser(self):
         """ Create a browser instance and print user agent info. """
@@ -425,7 +435,7 @@ class n2_gui_test_case(unittest.TestCase):
 
         self.page = await self.browser.newPage()
         await self.page.bringToFront()
-        await self.setup_error_handlers()
+        self.setup_error_handlers()
 
     def log_test(self, msg):
         global current_test
@@ -625,6 +635,16 @@ class n2_gui_test_case(unittest.TestCase):
 
         await self.browser.close()
 
+        if self.console_error:
+            msg = "Console log contains errors."
+            print(msg)
+            self.fail(msg)
+
+        if self.page_error:
+            msg = "There were errors on the page."
+            print(msg)
+            self.fail(msg)
+
     @parameterized.expand(n2_gui_test_models)
     def test_n2_gui(self, basename):
         if (basename[:2] == "__"):
